@@ -6,7 +6,6 @@ use warnings;
 use base qw( HTTP::Request Class::Accessor::Fast );
 
 use HTTP::Request::Common ();
-use URI;
 
 __PACKAGE__->mk_accessors( qw( opensearch_url opensearch_params ) );
 
@@ -22,6 +21,10 @@ WWW::OpenSearch::Request - Encapsulate an opensearch request
 
 =head2 new( $url, \%params )
 
+=head1 METHODS
+
+=head2 clone( )
+
 =head1 ACCESSORS
 
 =over 4
@@ -50,12 +53,12 @@ it under the same terms as Perl itself.
 =cut
 
 sub new {
-    my( $class, $os_url, $params ) = @_;
+    my ( $class, $os_url, $params ) = @_;
 
-    my( $uri, $post ) = $os_url->prepare_query( $params );
+    my ( $uri, $post ) = $os_url->prepare_query( $params );
 
     my $self;
-    if( lc $os_url->method eq 'post' ) {
+    if ( lc $os_url->method eq 'post' ) {
         $self = HTTP::Request::Common::POST( $uri, $post );
         bless $self, $class;
     }
@@ -69,4 +72,14 @@ sub new {
     return $self;
 }
 
+sub clone {
+    my $self = shift;
+    my $clone = bless $self->SUPER::clone, ref( $self );
+
+    $clone->opensearch_url( $self->opensearch_url );
+    $clone->opensearch_params( $self->opensearch_params );
+
+    return $clone;
+}
+
 1;
